# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationEventTopicVideo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationEventTopicVideo - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'pcSelf': 'QueueConversationEventTopicAddress',
            'id': 'str',
            'context': 'str',
            'audio_muted': 'bool',
            'video_muted': 'bool',
            'sharing_screen': 'bool',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'disconnect_type': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'msids': 'list[str]',
            'wrapup': 'QueueConversationEventTopicWrapup',
            'after_call_work': 'QueueConversationEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'pcSelf': 'self',
            'id': 'id',
            'context': 'context',
            'audio_muted': 'audioMuted',
            'video_muted': 'videoMuted',
            'sharing_screen': 'sharingScreen',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'disconnect_type': 'disconnectType',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'msids': 'msids',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._pcSelf = None
        self._id = None
        self._context = None
        self._audio_muted = None
        self._video_muted = None
        self._sharing_screen = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._disconnect_type = None
        self._connected_time = None
        self._disconnected_time = None
        self._msids = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this QueueConversationEventTopicVideo.


        :return: The state of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationEventTopicVideo.


        :param state: The state of this QueueConversationEventTopicVideo.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this QueueConversationEventTopicVideo.


        :return: The pcSelf of this QueueConversationEventTopicVideo.
        :rtype: QueueConversationEventTopicAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this QueueConversationEventTopicVideo.


        :param pcSelf: The pcSelf of this QueueConversationEventTopicVideo.
        :type: QueueConversationEventTopicAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def id(self):
        """
        Gets the id of this QueueConversationEventTopicVideo.


        :return: The id of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationEventTopicVideo.


        :param id: The id of this QueueConversationEventTopicVideo.
        :type: str
        """
        
        self._id = id

    @property
    def context(self):
        """
        Gets the context of this QueueConversationEventTopicVideo.


        :return: The context of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this QueueConversationEventTopicVideo.


        :param context: The context of this QueueConversationEventTopicVideo.
        :type: str
        """
        
        self._context = context

    @property
    def audio_muted(self):
        """
        Gets the audio_muted of this QueueConversationEventTopicVideo.


        :return: The audio_muted of this QueueConversationEventTopicVideo.
        :rtype: bool
        """
        return self._audio_muted

    @audio_muted.setter
    def audio_muted(self, audio_muted):
        """
        Sets the audio_muted of this QueueConversationEventTopicVideo.


        :param audio_muted: The audio_muted of this QueueConversationEventTopicVideo.
        :type: bool
        """
        
        self._audio_muted = audio_muted

    @property
    def video_muted(self):
        """
        Gets the video_muted of this QueueConversationEventTopicVideo.


        :return: The video_muted of this QueueConversationEventTopicVideo.
        :rtype: bool
        """
        return self._video_muted

    @video_muted.setter
    def video_muted(self, video_muted):
        """
        Sets the video_muted of this QueueConversationEventTopicVideo.


        :param video_muted: The video_muted of this QueueConversationEventTopicVideo.
        :type: bool
        """
        
        self._video_muted = video_muted

    @property
    def sharing_screen(self):
        """
        Gets the sharing_screen of this QueueConversationEventTopicVideo.


        :return: The sharing_screen of this QueueConversationEventTopicVideo.
        :rtype: bool
        """
        return self._sharing_screen

    @sharing_screen.setter
    def sharing_screen(self, sharing_screen):
        """
        Sets the sharing_screen of this QueueConversationEventTopicVideo.


        :param sharing_screen: The sharing_screen of this QueueConversationEventTopicVideo.
        :type: bool
        """
        
        self._sharing_screen = sharing_screen

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationEventTopicVideo.


        :return: The provider of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationEventTopicVideo.


        :param provider: The provider of this QueueConversationEventTopicVideo.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationEventTopicVideo.


        :return: The script_id of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationEventTopicVideo.


        :param script_id: The script_id of this QueueConversationEventTopicVideo.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationEventTopicVideo.


        :return: The peer_id of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationEventTopicVideo.


        :param peer_id: The peer_id of this QueueConversationEventTopicVideo.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationEventTopicVideo.


        :return: The disconnect_type of this QueueConversationEventTopicVideo.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationEventTopicVideo.


        :param disconnect_type: The disconnect_type of this QueueConversationEventTopicVideo.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationEventTopicVideo.


        :return: The connected_time of this QueueConversationEventTopicVideo.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationEventTopicVideo.


        :param connected_time: The connected_time of this QueueConversationEventTopicVideo.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationEventTopicVideo.


        :return: The disconnected_time of this QueueConversationEventTopicVideo.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationEventTopicVideo.


        :param disconnected_time: The disconnected_time of this QueueConversationEventTopicVideo.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def msids(self):
        """
        Gets the msids of this QueueConversationEventTopicVideo.


        :return: The msids of this QueueConversationEventTopicVideo.
        :rtype: list[str]
        """
        return self._msids

    @msids.setter
    def msids(self, msids):
        """
        Sets the msids of this QueueConversationEventTopicVideo.


        :param msids: The msids of this QueueConversationEventTopicVideo.
        :type: list[str]
        """
        
        self._msids = msids

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationEventTopicVideo.


        :return: The wrapup of this QueueConversationEventTopicVideo.
        :rtype: QueueConversationEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationEventTopicVideo.


        :param wrapup: The wrapup of this QueueConversationEventTopicVideo.
        :type: QueueConversationEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationEventTopicVideo.


        :return: The after_call_work of this QueueConversationEventTopicVideo.
        :rtype: QueueConversationEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationEventTopicVideo.


        :param after_call_work: The after_call_work of this QueueConversationEventTopicVideo.
        :type: QueueConversationEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationEventTopicVideo.


        :return: The after_call_work_required of this QueueConversationEventTopicVideo.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationEventTopicVideo.


        :param after_call_work_required: The after_call_work_required of this QueueConversationEventTopicVideo.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationEventTopicVideo.


        :return: The additional_properties of this QueueConversationEventTopicVideo.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationEventTopicVideo.


        :param additional_properties: The additional_properties of this QueueConversationEventTopicVideo.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateCoachingAppointmentRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateCoachingAppointmentRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'date_start': 'datetime',
            'length_in_minutes': 'int',
            'facilitator_id': 'str',
            'attendee_ids': 'list[str]',
            'conversation_ids': 'list[str]',
            'document_ids': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'date_start': 'dateStart',
            'length_in_minutes': 'lengthInMinutes',
            'facilitator_id': 'facilitatorId',
            'attendee_ids': 'attendeeIds',
            'conversation_ids': 'conversationIds',
            'document_ids': 'documentIds'
        }

        self._name = None
        self._description = None
        self._date_start = None
        self._length_in_minutes = None
        self._facilitator_id = None
        self._attendee_ids = None
        self._conversation_ids = None
        self._document_ids = None

    @property
    def name(self):
        """
        Gets the name of this CreateCoachingAppointmentRequest.
        The name of coaching appointment.

        :return: The name of this CreateCoachingAppointmentRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateCoachingAppointmentRequest.
        The name of coaching appointment.

        :param name: The name of this CreateCoachingAppointmentRequest.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateCoachingAppointmentRequest.
        The description of coaching appointment.

        :return: The description of this CreateCoachingAppointmentRequest.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateCoachingAppointmentRequest.
        The description of coaching appointment.

        :param description: The description of this CreateCoachingAppointmentRequest.
        :type: str
        """
        
        self._description = description

    @property
    def date_start(self):
        """
        Gets the date_start of this CreateCoachingAppointmentRequest.
        The date/time the coaching appointment starts. Times will be rounded down to the minute. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_start of this CreateCoachingAppointmentRequest.
        :rtype: datetime
        """
        return self._date_start

    @date_start.setter
    def date_start(self, date_start):
        """
        Sets the date_start of this CreateCoachingAppointmentRequest.
        The date/time the coaching appointment starts. Times will be rounded down to the minute. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_start: The date_start of this CreateCoachingAppointmentRequest.
        :type: datetime
        """
        
        self._date_start = date_start

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this CreateCoachingAppointmentRequest.
        The duration of coaching appointment in minutes.

        :return: The length_in_minutes of this CreateCoachingAppointmentRequest.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this CreateCoachingAppointmentRequest.
        The duration of coaching appointment in minutes.

        :param length_in_minutes: The length_in_minutes of this CreateCoachingAppointmentRequest.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def facilitator_id(self):
        """
        Gets the facilitator_id of this CreateCoachingAppointmentRequest.
        The facilitator ID of coaching appointment.

        :return: The facilitator_id of this CreateCoachingAppointmentRequest.
        :rtype: str
        """
        return self._facilitator_id

    @facilitator_id.setter
    def facilitator_id(self, facilitator_id):
        """
        Sets the facilitator_id of this CreateCoachingAppointmentRequest.
        The facilitator ID of coaching appointment.

        :param facilitator_id: The facilitator_id of this CreateCoachingAppointmentRequest.
        :type: str
        """
        
        self._facilitator_id = facilitator_id

    @property
    def attendee_ids(self):
        """
        Gets the attendee_ids of this CreateCoachingAppointmentRequest.
        IDs of attendees in the coaching appointment.

        :return: The attendee_ids of this CreateCoachingAppointmentRequest.
        :rtype: list[str]
        """
        return self._attendee_ids

    @attendee_ids.setter
    def attendee_ids(self, attendee_ids):
        """
        Sets the attendee_ids of this CreateCoachingAppointmentRequest.
        IDs of attendees in the coaching appointment.

        :param attendee_ids: The attendee_ids of this CreateCoachingAppointmentRequest.
        :type: list[str]
        """
        
        self._attendee_ids = attendee_ids

    @property
    def conversation_ids(self):
        """
        Gets the conversation_ids of this CreateCoachingAppointmentRequest.
        IDs of conversations associated with this coaching appointment.

        :return: The conversation_ids of this CreateCoachingAppointmentRequest.
        :rtype: list[str]
        """
        return self._conversation_ids

    @conversation_ids.setter
    def conversation_ids(self, conversation_ids):
        """
        Sets the conversation_ids of this CreateCoachingAppointmentRequest.
        IDs of conversations associated with this coaching appointment.

        :param conversation_ids: The conversation_ids of this CreateCoachingAppointmentRequest.
        :type: list[str]
        """
        
        self._conversation_ids = conversation_ids

    @property
    def document_ids(self):
        """
        Gets the document_ids of this CreateCoachingAppointmentRequest.
        IDs of documents associated with this coaching appointment.

        :return: The document_ids of this CreateCoachingAppointmentRequest.
        :rtype: list[str]
        """
        return self._document_ids

    @document_ids.setter
    def document_ids(self, document_ids):
        """
        Sets the document_ids of this CreateCoachingAppointmentRequest.
        IDs of documents associated with this coaching appointment.

        :param document_ids: The document_ids of this CreateCoachingAppointmentRequest.
        :type: list[str]
        """
        
        self._document_ids = document_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScimV2Group(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScimV2Group - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'schemas': 'list[str]',
            'display_name': 'str',
            'external_id': 'str',
            'members': 'list[ScimV2MemberReference]',
            'meta': 'ScimMetadata'
        }

        self.attribute_map = {
            'id': 'id',
            'schemas': 'schemas',
            'display_name': 'displayName',
            'external_id': 'externalId',
            'members': 'members',
            'meta': 'meta'
        }

        self._id = None
        self._schemas = None
        self._display_name = None
        self._external_id = None
        self._members = None
        self._meta = None

    @property
    def id(self):
        """
        Gets the id of this ScimV2Group.
        The ID of the SCIM resource. Set by the service provider. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readOnly\". \"returned\" is set to \"always\".

        :return: The id of this ScimV2Group.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScimV2Group.
        The ID of the SCIM resource. Set by the service provider. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readOnly\". \"returned\" is set to \"always\".

        :param id: The id of this ScimV2Group.
        :type: str
        """
        
        self._id = id

    @property
    def schemas(self):
        """
        Gets the schemas of this ScimV2Group.
        The list of supported schemas.

        :return: The schemas of this ScimV2Group.
        :rtype: list[str]
        """
        return self._schemas

    @schemas.setter
    def schemas(self, schemas):
        """
        Sets the schemas of this ScimV2Group.
        The list of supported schemas.

        :param schemas: The schemas of this ScimV2Group.
        :type: list[str]
        """
        
        self._schemas = schemas

    @property
    def display_name(self):
        """
        Gets the display_name of this ScimV2Group.
        The display name of the group.

        :return: The display_name of this ScimV2Group.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ScimV2Group.
        The display name of the group.

        :param display_name: The display_name of this ScimV2Group.
        :type: str
        """
        
        self._display_name = display_name

    @property
    def external_id(self):
        """
        Gets the external_id of this ScimV2Group.
        The external ID of the group. Set by the provisioning client. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readWrite\".

        :return: The external_id of this ScimV2Group.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """
        Sets the external_id of this ScimV2Group.
        The external ID of the group. Set by the provisioning client. \"caseExact\" is set to \"true\". \"mutability\" is set to \"readWrite\".

        :param external_id: The external_id of this ScimV2Group.
        :type: str
        """
        
        self._external_id = external_id

    @property
    def members(self):
        """
        Gets the members of this ScimV2Group.
        The list of members in the group.

        :return: The members of this ScimV2Group.
        :rtype: list[ScimV2MemberReference]
        """
        return self._members

    @members.setter
    def members(self, members):
        """
        Sets the members of this ScimV2Group.
        The list of members in the group.

        :param members: The members of this ScimV2Group.
        :type: list[ScimV2MemberReference]
        """
        
        self._members = members

    @property
    def meta(self):
        """
        Gets the meta of this ScimV2Group.
        The metadata of the SCIM resource.

        :return: The meta of this ScimV2Group.
        :rtype: ScimMetadata
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """
        Sets the meta of this ScimV2Group.
        The metadata of the SCIM resource.

        :param meta: The meta of this ScimV2Group.
        :type: ScimMetadata
        """
        
        self._meta = meta

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateQueueRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateQueueRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'division': 'WritableDivision',
            'description': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'member_count': 'int',
            'media_settings': 'dict(str, MediaSetting)',
            'routing_rules': 'list[RoutingRule]',
            'bullseye': 'Bullseye',
            'acw_settings': 'AcwSettings',
            'skill_evaluation_method': 'str',
            'queue_flow': 'DomainEntityRef',
            'whisper_prompt': 'DomainEntityRef',
            'auto_answer_only': 'bool',
            'enable_transcription': 'bool',
            'enable_manual_assignment': 'bool',
            'calling_party_name': 'str',
            'calling_party_number': 'str',
            'default_scripts': 'dict(str, Script)',
            'outbound_messaging_addresses': 'QueueMessagingAddresses',
            'outbound_email_address': 'QueueEmailAddress',
            'source_queue_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'division': 'division',
            'description': 'description',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'member_count': 'memberCount',
            'media_settings': 'mediaSettings',
            'routing_rules': 'routingRules',
            'bullseye': 'bullseye',
            'acw_settings': 'acwSettings',
            'skill_evaluation_method': 'skillEvaluationMethod',
            'queue_flow': 'queueFlow',
            'whisper_prompt': 'whisperPrompt',
            'auto_answer_only': 'autoAnswerOnly',
            'enable_transcription': 'enableTranscription',
            'enable_manual_assignment': 'enableManualAssignment',
            'calling_party_name': 'callingPartyName',
            'calling_party_number': 'callingPartyNumber',
            'default_scripts': 'defaultScripts',
            'outbound_messaging_addresses': 'outboundMessagingAddresses',
            'outbound_email_address': 'outboundEmailAddress',
            'source_queue_id': 'sourceQueueId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._division = None
        self._description = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._member_count = None
        self._media_settings = None
        self._routing_rules = None
        self._bullseye = None
        self._acw_settings = None
        self._skill_evaluation_method = None
        self._queue_flow = None
        self._whisper_prompt = None
        self._auto_answer_only = None
        self._enable_transcription = None
        self._enable_manual_assignment = None
        self._calling_party_name = None
        self._calling_party_number = None
        self._default_scripts = None
        self._outbound_messaging_addresses = None
        self._outbound_email_address = None
        self._source_queue_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CreateQueueRequest.
        The globally unique identifier for the object.

        :return: The id of this CreateQueueRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CreateQueueRequest.
        The globally unique identifier for the object.

        :param id: The id of this CreateQueueRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CreateQueueRequest.
        The queue name

        :return: The name of this CreateQueueRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateQueueRequest.
        The queue name

        :param name: The name of this CreateQueueRequest.
        :type: str
        """
        
        self._name = name

    @property
    def division(self):
        """
        Gets the division of this CreateQueueRequest.
        The division to which this entity belongs.

        :return: The division of this CreateQueueRequest.
        :rtype: WritableDivision
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this CreateQueueRequest.
        The division to which this entity belongs.

        :param division: The division of this CreateQueueRequest.
        :type: WritableDivision
        """
        
        self._division = division

    @property
    def description(self):
        """
        Gets the description of this CreateQueueRequest.
        The queue description.

        :return: The description of this CreateQueueRequest.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateQueueRequest.
        The queue description.

        :param description: The description of this CreateQueueRequest.
        :type: str
        """
        
        self._description = description

    @property
    def date_created(self):
        """
        Gets the date_created of this CreateQueueRequest.
        The date the queue was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this CreateQueueRequest.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CreateQueueRequest.
        The date the queue was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this CreateQueueRequest.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CreateQueueRequest.
        The date of the last modification to the queue. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this CreateQueueRequest.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CreateQueueRequest.
        The date of the last modification to the queue. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this CreateQueueRequest.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this CreateQueueRequest.
        The ID of the user that last modified the queue.

        :return: The modified_by of this CreateQueueRequest.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this CreateQueueRequest.
        The ID of the user that last modified the queue.

        :param modified_by: The modified_by of this CreateQueueRequest.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this CreateQueueRequest.
        The ID of the user that created the queue.

        :return: The created_by of this CreateQueueRequest.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this CreateQueueRequest.
        The ID of the user that created the queue.

        :param created_by: The created_by of this CreateQueueRequest.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def member_count(self):
        """
        Gets the member_count of this CreateQueueRequest.
        The number of users in the queue.

        :return: The member_count of this CreateQueueRequest.
        :rtype: int
        """
        return self._member_count

    @member_count.setter
    def member_count(self, member_count):
        """
        Sets the member_count of this CreateQueueRequest.
        The number of users in the queue.

        :param member_count: The member_count of this CreateQueueRequest.
        :type: int
        """
        
        self._member_count = member_count

    @property
    def media_settings(self):
        """
        Gets the media_settings of this CreateQueueRequest.
        The media settings for the queue. Valid key values: CALL, CALLBACK, CHAT, EMAIL, MESSAGE, SOCIAL_EXPRESSION, VIDEO_COMM

        :return: The media_settings of this CreateQueueRequest.
        :rtype: dict(str, MediaSetting)
        """
        return self._media_settings

    @media_settings.setter
    def media_settings(self, media_settings):
        """
        Sets the media_settings of this CreateQueueRequest.
        The media settings for the queue. Valid key values: CALL, CALLBACK, CHAT, EMAIL, MESSAGE, SOCIAL_EXPRESSION, VIDEO_COMM

        :param media_settings: The media_settings of this CreateQueueRequest.
        :type: dict(str, MediaSetting)
        """
        
        self._media_settings = media_settings

    @property
    def routing_rules(self):
        """
        Gets the routing_rules of this CreateQueueRequest.
        The routing rules for the queue, used for routing to known or preferred agents.

        :return: The routing_rules of this CreateQueueRequest.
        :rtype: list[RoutingRule]
        """
        return self._routing_rules

    @routing_rules.setter
    def routing_rules(self, routing_rules):
        """
        Sets the routing_rules of this CreateQueueRequest.
        The routing rules for the queue, used for routing to known or preferred agents.

        :param routing_rules: The routing_rules of this CreateQueueRequest.
        :type: list[RoutingRule]
        """
        
        self._routing_rules = routing_rules

    @property
    def bullseye(self):
        """
        Gets the bullseye of this CreateQueueRequest.
        The bulls-eye settings for the queue.

        :return: The bullseye of this CreateQueueRequest.
        :rtype: Bullseye
        """
        return self._bullseye

    @bullseye.setter
    def bullseye(self, bullseye):
        """
        Sets the bullseye of this CreateQueueRequest.
        The bulls-eye settings for the queue.

        :param bullseye: The bullseye of this CreateQueueRequest.
        :type: Bullseye
        """
        
        self._bullseye = bullseye

    @property
    def acw_settings(self):
        """
        Gets the acw_settings of this CreateQueueRequest.
        The ACW settings for the queue.

        :return: The acw_settings of this CreateQueueRequest.
        :rtype: AcwSettings
        """
        return self._acw_settings

    @acw_settings.setter
    def acw_settings(self, acw_settings):
        """
        Sets the acw_settings of this CreateQueueRequest.
        The ACW settings for the queue.

        :param acw_settings: The acw_settings of this CreateQueueRequest.
        :type: AcwSettings
        """
        
        self._acw_settings = acw_settings

    @property
    def skill_evaluation_method(self):
        """
        Gets the skill_evaluation_method of this CreateQueueRequest.
        The skill evaluation method to use when routing conversations.

        :return: The skill_evaluation_method of this CreateQueueRequest.
        :rtype: str
        """
        return self._skill_evaluation_method

    @skill_evaluation_method.setter
    def skill_evaluation_method(self, skill_evaluation_method):
        """
        Sets the skill_evaluation_method of this CreateQueueRequest.
        The skill evaluation method to use when routing conversations.

        :param skill_evaluation_method: The skill_evaluation_method of this CreateQueueRequest.
        :type: str
        """
        allowed_values = ["NONE", "BEST", "ALL"]
        if skill_evaluation_method.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for skill_evaluation_method -> " + skill_evaluation_method)
            self._skill_evaluation_method = "outdated_sdk_version"
        else:
            self._skill_evaluation_method = skill_evaluation_method

    @property
    def queue_flow(self):
        """
        Gets the queue_flow of this CreateQueueRequest.
        The in-queue flow to use for conversations waiting in queue.

        :return: The queue_flow of this CreateQueueRequest.
        :rtype: DomainEntityRef
        """
        return self._queue_flow

    @queue_flow.setter
    def queue_flow(self, queue_flow):
        """
        Sets the queue_flow of this CreateQueueRequest.
        The in-queue flow to use for conversations waiting in queue.

        :param queue_flow: The queue_flow of this CreateQueueRequest.
        :type: DomainEntityRef
        """
        
        self._queue_flow = queue_flow

    @property
    def whisper_prompt(self):
        """
        Gets the whisper_prompt of this CreateQueueRequest.
        The prompt used for whisper on the queue, if configured.

        :return: The whisper_prompt of this CreateQueueRequest.
        :rtype: DomainEntityRef
        """
        return self._whisper_prompt

    @whisper_prompt.setter
    def whisper_prompt(self, whisper_prompt):
        """
        Sets the whisper_prompt of this CreateQueueRequest.
        The prompt used for whisper on the queue, if configured.

        :param whisper_prompt: The whisper_prompt of this CreateQueueRequest.
        :type: DomainEntityRef
        """
        
        self._whisper_prompt = whisper_prompt

    @property
    def auto_answer_only(self):
        """
        Gets the auto_answer_only of this CreateQueueRequest.
        Specifies whether the configured whisper should play for all ACD calls, or only for those which are auto-answered.

        :return: The auto_answer_only of this CreateQueueRequest.
        :rtype: bool
        """
        return self._auto_answer_only

    @auto_answer_only.setter
    def auto_answer_only(self, auto_answer_only):
        """
        Sets the auto_answer_only of this CreateQueueRequest.
        Specifies whether the configured whisper should play for all ACD calls, or only for those which are auto-answered.

        :param auto_answer_only: The auto_answer_only of this CreateQueueRequest.
        :type: bool
        """
        
        self._auto_answer_only = auto_answer_only

    @property
    def enable_transcription(self):
        """
        Gets the enable_transcription of this CreateQueueRequest.
        Indicates whether voice transcription is enabled for this queue.

        :return: The enable_transcription of this CreateQueueRequest.
        :rtype: bool
        """
        return self._enable_transcription

    @enable_transcription.setter
    def enable_transcription(self, enable_transcription):
        """
        Sets the enable_transcription of this CreateQueueRequest.
        Indicates whether voice transcription is enabled for this queue.

        :param enable_transcription: The enable_transcription of this CreateQueueRequest.
        :type: bool
        """
        
        self._enable_transcription = enable_transcription

    @property
    def enable_manual_assignment(self):
        """
        Gets the enable_manual_assignment of this CreateQueueRequest.
        Indicates whether manual assignment is enabled for this queue.

        :return: The enable_manual_assignment of this CreateQueueRequest.
        :rtype: bool
        """
        return self._enable_manual_assignment

    @enable_manual_assignment.setter
    def enable_manual_assignment(self, enable_manual_assignment):
        """
        Sets the enable_manual_assignment of this CreateQueueRequest.
        Indicates whether manual assignment is enabled for this queue.

        :param enable_manual_assignment: The enable_manual_assignment of this CreateQueueRequest.
        :type: bool
        """
        
        self._enable_manual_assignment = enable_manual_assignment

    @property
    def calling_party_name(self):
        """
        Gets the calling_party_name of this CreateQueueRequest.
        The name to use for caller identification for outbound calls from this queue.

        :return: The calling_party_name of this CreateQueueRequest.
        :rtype: str
        """
        return self._calling_party_name

    @calling_party_name.setter
    def calling_party_name(self, calling_party_name):
        """
        Sets the calling_party_name of this CreateQueueRequest.
        The name to use for caller identification for outbound calls from this queue.

        :param calling_party_name: The calling_party_name of this CreateQueueRequest.
        :type: str
        """
        
        self._calling_party_name = calling_party_name

    @property
    def calling_party_number(self):
        """
        Gets the calling_party_number of this CreateQueueRequest.
        The phone number to use for caller identification for outbound calls from this queue.

        :return: The calling_party_number of this CreateQueueRequest.
        :rtype: str
        """
        return self._calling_party_number

    @calling_party_number.setter
    def calling_party_number(self, calling_party_number):
        """
        Sets the calling_party_number of this CreateQueueRequest.
        The phone number to use for caller identification for outbound calls from this queue.

        :param calling_party_number: The calling_party_number of this CreateQueueRequest.
        :type: str
        """
        
        self._calling_party_number = calling_party_number

    @property
    def default_scripts(self):
        """
        Gets the default_scripts of this CreateQueueRequest.
        The default script Ids for the communication types.

        :return: The default_scripts of this CreateQueueRequest.
        :rtype: dict(str, Script)
        """
        return self._default_scripts

    @default_scripts.setter
    def default_scripts(self, default_scripts):
        """
        Sets the default_scripts of this CreateQueueRequest.
        The default script Ids for the communication types.

        :param default_scripts: The default_scripts of this CreateQueueRequest.
        :type: dict(str, Script)
        """
        
        self._default_scripts = default_scripts

    @property
    def outbound_messaging_addresses(self):
        """
        Gets the outbound_messaging_addresses of this CreateQueueRequest.
        The messaging addresses for the queue.

        :return: The outbound_messaging_addresses of this CreateQueueRequest.
        :rtype: QueueMessagingAddresses
        """
        return self._outbound_messaging_addresses

    @outbound_messaging_addresses.setter
    def outbound_messaging_addresses(self, outbound_messaging_addresses):
        """
        Sets the outbound_messaging_addresses of this CreateQueueRequest.
        The messaging addresses for the queue.

        :param outbound_messaging_addresses: The outbound_messaging_addresses of this CreateQueueRequest.
        :type: QueueMessagingAddresses
        """
        
        self._outbound_messaging_addresses = outbound_messaging_addresses

    @property
    def outbound_email_address(self):
        """
        Gets the outbound_email_address of this CreateQueueRequest.


        :return: The outbound_email_address of this CreateQueueRequest.
        :rtype: QueueEmailAddress
        """
        return self._outbound_email_address

    @outbound_email_address.setter
    def outbound_email_address(self, outbound_email_address):
        """
        Sets the outbound_email_address of this CreateQueueRequest.


        :param outbound_email_address: The outbound_email_address of this CreateQueueRequest.
        :type: QueueEmailAddress
        """
        
        self._outbound_email_address = outbound_email_address

    @property
    def source_queue_id(self):
        """
        Gets the source_queue_id of this CreateQueueRequest.
        The id of an existing queue to copy the settings from when creating a new queue.

        :return: The source_queue_id of this CreateQueueRequest.
        :rtype: str
        """
        return self._source_queue_id

    @source_queue_id.setter
    def source_queue_id(self, source_queue_id):
        """
        Sets the source_queue_id of this CreateQueueRequest.
        The id of an existing queue to copy the settings from when creating a new queue.

        :param source_queue_id: The source_queue_id of this CreateQueueRequest.
        :type: str
        """
        
        self._source_queue_id = source_queue_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CreateQueueRequest.
        The URI for this object

        :return: The self_uri of this CreateQueueRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CreateQueueRequest.
        The URI for this object

        :param self_uri: The self_uri of this CreateQueueRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserTokensTopicTokenNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserTokensTopicTokenNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user': 'UserTokensTopicUriReference',
            'ip_address': 'str',
            'date_created': 'str',
            'token_expiration_date': 'str',
            'session_id': 'str',
            'client_id': 'str',
            'token_hash': 'str'
        }

        self.attribute_map = {
            'user': 'user',
            'ip_address': 'ipAddress',
            'date_created': 'dateCreated',
            'token_expiration_date': 'tokenExpirationDate',
            'session_id': 'sessionId',
            'client_id': 'clientId',
            'token_hash': 'tokenHash'
        }

        self._user = None
        self._ip_address = None
        self._date_created = None
        self._token_expiration_date = None
        self._session_id = None
        self._client_id = None
        self._token_hash = None

    @property
    def user(self):
        """
        Gets the user of this UserTokensTopicTokenNotification.


        :return: The user of this UserTokensTopicTokenNotification.
        :rtype: UserTokensTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this UserTokensTopicTokenNotification.


        :param user: The user of this UserTokensTopicTokenNotification.
        :type: UserTokensTopicUriReference
        """
        
        self._user = user

    @property
    def ip_address(self):
        """
        Gets the ip_address of this UserTokensTopicTokenNotification.


        :return: The ip_address of this UserTokensTopicTokenNotification.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this UserTokensTopicTokenNotification.


        :param ip_address: The ip_address of this UserTokensTopicTokenNotification.
        :type: str
        """
        
        self._ip_address = ip_address

    @property
    def date_created(self):
        """
        Gets the date_created of this UserTokensTopicTokenNotification.


        :return: The date_created of this UserTokensTopicTokenNotification.
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this UserTokensTopicTokenNotification.


        :param date_created: The date_created of this UserTokensTopicTokenNotification.
        :type: str
        """
        
        self._date_created = date_created

    @property
    def token_expiration_date(self):
        """
        Gets the token_expiration_date of this UserTokensTopicTokenNotification.


        :return: The token_expiration_date of this UserTokensTopicTokenNotification.
        :rtype: str
        """
        return self._token_expiration_date

    @token_expiration_date.setter
    def token_expiration_date(self, token_expiration_date):
        """
        Sets the token_expiration_date of this UserTokensTopicTokenNotification.


        :param token_expiration_date: The token_expiration_date of this UserTokensTopicTokenNotification.
        :type: str
        """
        
        self._token_expiration_date = token_expiration_date

    @property
    def session_id(self):
        """
        Gets the session_id of this UserTokensTopicTokenNotification.


        :return: The session_id of this UserTokensTopicTokenNotification.
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this UserTokensTopicTokenNotification.


        :param session_id: The session_id of this UserTokensTopicTokenNotification.
        :type: str
        """
        
        self._session_id = session_id

    @property
    def client_id(self):
        """
        Gets the client_id of this UserTokensTopicTokenNotification.


        :return: The client_id of this UserTokensTopicTokenNotification.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this UserTokensTopicTokenNotification.


        :param client_id: The client_id of this UserTokensTopicTokenNotification.
        :type: str
        """
        
        self._client_id = client_id

    @property
    def token_hash(self):
        """
        Gets the token_hash of this UserTokensTopicTokenNotification.


        :return: The token_hash of this UserTokensTopicTokenNotification.
        :rtype: str
        """
        return self._token_hash

    @token_hash.setter
    def token_hash(self, token_hash):
        """
        Sets the token_hash of this UserTokensTopicTokenNotification.


        :param token_hash: The token_hash of this UserTokensTopicTokenNotification.
        :type: str
        """
        
        self._token_hash = token_hash

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AgentActivityChangedTopicAgentActivity(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AgentActivityChangedTopicAgentActivity - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'routing_status': 'AgentActivityChangedTopicRoutingStatus',
            'presence': 'AgentActivityChangedTopicPresence',
            'out_of_office': 'AgentActivityChangedTopicOutOfOffice',
            'active_queue_ids': 'list[str]',
            'date_active_queues_changed': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'routing_status': 'routingStatus',
            'presence': 'presence',
            'out_of_office': 'outOfOffice',
            'active_queue_ids': 'activeQueueIds',
            'date_active_queues_changed': 'dateActiveQueuesChanged'
        }

        self._id = None
        self._routing_status = None
        self._presence = None
        self._out_of_office = None
        self._active_queue_ids = None
        self._date_active_queues_changed = None

    @property
    def id(self):
        """
        Gets the id of this AgentActivityChangedTopicAgentActivity.


        :return: The id of this AgentActivityChangedTopicAgentActivity.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AgentActivityChangedTopicAgentActivity.


        :param id: The id of this AgentActivityChangedTopicAgentActivity.
        :type: str
        """
        
        self._id = id

    @property
    def routing_status(self):
        """
        Gets the routing_status of this AgentActivityChangedTopicAgentActivity.


        :return: The routing_status of this AgentActivityChangedTopicAgentActivity.
        :rtype: AgentActivityChangedTopicRoutingStatus
        """
        return self._routing_status

    @routing_status.setter
    def routing_status(self, routing_status):
        """
        Sets the routing_status of this AgentActivityChangedTopicAgentActivity.


        :param routing_status: The routing_status of this AgentActivityChangedTopicAgentActivity.
        :type: AgentActivityChangedTopicRoutingStatus
        """
        
        self._routing_status = routing_status

    @property
    def presence(self):
        """
        Gets the presence of this AgentActivityChangedTopicAgentActivity.


        :return: The presence of this AgentActivityChangedTopicAgentActivity.
        :rtype: AgentActivityChangedTopicPresence
        """
        return self._presence

    @presence.setter
    def presence(self, presence):
        """
        Sets the presence of this AgentActivityChangedTopicAgentActivity.


        :param presence: The presence of this AgentActivityChangedTopicAgentActivity.
        :type: AgentActivityChangedTopicPresence
        """
        
        self._presence = presence

    @property
    def out_of_office(self):
        """
        Gets the out_of_office of this AgentActivityChangedTopicAgentActivity.


        :return: The out_of_office of this AgentActivityChangedTopicAgentActivity.
        :rtype: AgentActivityChangedTopicOutOfOffice
        """
        return self._out_of_office

    @out_of_office.setter
    def out_of_office(self, out_of_office):
        """
        Sets the out_of_office of this AgentActivityChangedTopicAgentActivity.


        :param out_of_office: The out_of_office of this AgentActivityChangedTopicAgentActivity.
        :type: AgentActivityChangedTopicOutOfOffice
        """
        
        self._out_of_office = out_of_office

    @property
    def active_queue_ids(self):
        """
        Gets the active_queue_ids of this AgentActivityChangedTopicAgentActivity.


        :return: The active_queue_ids of this AgentActivityChangedTopicAgentActivity.
        :rtype: list[str]
        """
        return self._active_queue_ids

    @active_queue_ids.setter
    def active_queue_ids(self, active_queue_ids):
        """
        Sets the active_queue_ids of this AgentActivityChangedTopicAgentActivity.


        :param active_queue_ids: The active_queue_ids of this AgentActivityChangedTopicAgentActivity.
        :type: list[str]
        """
        
        self._active_queue_ids = active_queue_ids

    @property
    def date_active_queues_changed(self):
        """
        Gets the date_active_queues_changed of this AgentActivityChangedTopicAgentActivity.


        :return: The date_active_queues_changed of this AgentActivityChangedTopicAgentActivity.
        :rtype: datetime
        """
        return self._date_active_queues_changed

    @date_active_queues_changed.setter
    def date_active_queues_changed(self, date_active_queues_changed):
        """
        Sets the date_active_queues_changed of this AgentActivityChangedTopicAgentActivity.


        :param date_active_queues_changed: The date_active_queues_changed of this AgentActivityChangedTopicAgentActivity.
        :type: datetime
        """
        
        self._date_active_queues_changed = date_active_queues_changed

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationSocialExpressionEventTopicCobrowse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationSocialExpressionEventTopicCobrowse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'disconnect_type': 'str',
            'id': 'str',
            'pcSelf': 'QueueConversationSocialExpressionEventTopicAddress',
            'room_id': 'str',
            'cobrowse_session_id': 'str',
            'cobrowse_role': 'str',
            'controlling': 'list[str]',
            'viewer_url': 'str',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'provider_event_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'wrapup': 'QueueConversationSocialExpressionEventTopicWrapup',
            'after_call_work': 'QueueConversationSocialExpressionEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'disconnect_type': 'disconnectType',
            'id': 'id',
            'pcSelf': 'self',
            'room_id': 'roomId',
            'cobrowse_session_id': 'cobrowseSessionId',
            'cobrowse_role': 'cobrowseRole',
            'controlling': 'controlling',
            'viewer_url': 'viewerUrl',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'provider_event_time': 'providerEventTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._disconnect_type = None
        self._id = None
        self._pcSelf = None
        self._room_id = None
        self._cobrowse_session_id = None
        self._cobrowse_role = None
        self._controlling = None
        self._viewer_url = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._provider_event_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The state of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param state: The state of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The disconnect_type of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param disconnect_type: The disconnect_type of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def id(self):
        """
        Gets the id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param id: The id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._id = id

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The pcSelf of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: QueueConversationSocialExpressionEventTopicAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param pcSelf: The pcSelf of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: QueueConversationSocialExpressionEventTopicAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def room_id(self):
        """
        Gets the room_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The room_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param room_id: The room_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._room_id = room_id

    @property
    def cobrowse_session_id(self):
        """
        Gets the cobrowse_session_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The cobrowse_session_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._cobrowse_session_id

    @cobrowse_session_id.setter
    def cobrowse_session_id(self, cobrowse_session_id):
        """
        Sets the cobrowse_session_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param cobrowse_session_id: The cobrowse_session_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._cobrowse_session_id = cobrowse_session_id

    @property
    def cobrowse_role(self):
        """
        Gets the cobrowse_role of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The cobrowse_role of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._cobrowse_role

    @cobrowse_role.setter
    def cobrowse_role(self, cobrowse_role):
        """
        Sets the cobrowse_role of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param cobrowse_role: The cobrowse_role of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._cobrowse_role = cobrowse_role

    @property
    def controlling(self):
        """
        Gets the controlling of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The controlling of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: list[str]
        """
        return self._controlling

    @controlling.setter
    def controlling(self, controlling):
        """
        Sets the controlling of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param controlling: The controlling of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: list[str]
        """
        
        self._controlling = controlling

    @property
    def viewer_url(self):
        """
        Gets the viewer_url of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The viewer_url of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._viewer_url

    @viewer_url.setter
    def viewer_url(self, viewer_url):
        """
        Sets the viewer_url of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param viewer_url: The viewer_url of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._viewer_url = viewer_url

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The provider of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param provider: The provider of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The script_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param script_id: The script_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The peer_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param peer_id: The peer_id of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def provider_event_time(self):
        """
        Gets the provider_event_time of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The provider_event_time of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: datetime
        """
        return self._provider_event_time

    @provider_event_time.setter
    def provider_event_time(self, provider_event_time):
        """
        Sets the provider_event_time of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param provider_event_time: The provider_event_time of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: datetime
        """
        
        self._provider_event_time = provider_event_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The connected_time of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param connected_time: The connected_time of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The disconnected_time of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param disconnected_time: The disconnected_time of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The wrapup of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: QueueConversationSocialExpressionEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param wrapup: The wrapup of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: QueueConversationSocialExpressionEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The after_call_work of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: QueueConversationSocialExpressionEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param after_call_work: The after_call_work of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: QueueConversationSocialExpressionEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The after_call_work_required of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param after_call_work_required: The after_call_work_required of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationSocialExpressionEventTopicCobrowse.


        :return: The additional_properties of this QueueConversationSocialExpressionEventTopicCobrowse.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationSocialExpressionEventTopicCobrowse.


        :param additional_properties: The additional_properties of this QueueConversationSocialExpressionEventTopicCobrowse.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Action(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Action - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'integration_id': 'str',
            'category': 'str',
            'contract': 'ActionContract',
            'version': 'int',
            'secure': 'bool',
            'config': 'ActionConfig',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'integration_id': 'integrationId',
            'category': 'category',
            'contract': 'contract',
            'version': 'version',
            'secure': 'secure',
            'config': 'config',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._integration_id = None
        self._category = None
        self._contract = None
        self._version = None
        self._secure = None
        self._config = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Action.
        The globally unique identifier for the object.

        :return: The id of this Action.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Action.
        The globally unique identifier for the object.

        :param id: The id of this Action.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Action.


        :return: The name of this Action.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Action.


        :param name: The name of this Action.
        :type: str
        """
        
        self._name = name

    @property
    def integration_id(self):
        """
        Gets the integration_id of this Action.
        The ID of the integration for which this action is associated

        :return: The integration_id of this Action.
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """
        Sets the integration_id of this Action.
        The ID of the integration for which this action is associated

        :param integration_id: The integration_id of this Action.
        :type: str
        """
        
        self._integration_id = integration_id

    @property
    def category(self):
        """
        Gets the category of this Action.
        Category of Action

        :return: The category of this Action.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this Action.
        Category of Action

        :param category: The category of this Action.
        :type: str
        """
        
        self._category = category

    @property
    def contract(self):
        """
        Gets the contract of this Action.
        Action contract

        :return: The contract of this Action.
        :rtype: ActionContract
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """
        Sets the contract of this Action.
        Action contract

        :param contract: The contract of this Action.
        :type: ActionContract
        """
        
        self._contract = contract

    @property
    def version(self):
        """
        Gets the version of this Action.
        Version of this action

        :return: The version of this Action.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Action.
        Version of this action

        :param version: The version of this Action.
        :type: int
        """
        
        self._version = version

    @property
    def secure(self):
        """
        Gets the secure of this Action.
        Indication of whether or not the action is designed to accept sensitive data

        :return: The secure of this Action.
        :rtype: bool
        """
        return self._secure

    @secure.setter
    def secure(self, secure):
        """
        Sets the secure of this Action.
        Indication of whether or not the action is designed to accept sensitive data

        :param secure: The secure of this Action.
        :type: bool
        """
        
        self._secure = secure

    @property
    def config(self):
        """
        Gets the config of this Action.
        Configuration to support request and response processing

        :return: The config of this Action.
        :rtype: ActionConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this Action.
        Configuration to support request and response processing

        :param config: The config of this Action.
        :type: ActionConfig
        """
        
        self._config = config

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Action.
        The URI for this object

        :return: The self_uri of this Action.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Action.
        The URI for this object

        :param self_uri: The self_uri of this Action.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HistoricalAdherenceDayMetrics(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HistoricalAdherenceDayMetrics - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'day_start_offset_secs': 'int',
            'adherence_schedule_secs': 'int',
            'conformance_schedule_secs': 'int',
            'conformance_actual_secs': 'int',
            'exception_count': 'int',
            'exception_duration_secs': 'int',
            'impact_seconds': 'int',
            'schedule_length_secs': 'int',
            'actual_length_secs': 'int',
            'adherence_percentage': 'float',
            'conformance_percentage': 'float'
        }

        self.attribute_map = {
            'day_start_offset_secs': 'dayStartOffsetSecs',
            'adherence_schedule_secs': 'adherenceScheduleSecs',
            'conformance_schedule_secs': 'conformanceScheduleSecs',
            'conformance_actual_secs': 'conformanceActualSecs',
            'exception_count': 'exceptionCount',
            'exception_duration_secs': 'exceptionDurationSecs',
            'impact_seconds': 'impactSeconds',
            'schedule_length_secs': 'scheduleLengthSecs',
            'actual_length_secs': 'actualLengthSecs',
            'adherence_percentage': 'adherencePercentage',
            'conformance_percentage': 'conformancePercentage'
        }

        self._day_start_offset_secs = None
        self._adherence_schedule_secs = None
        self._conformance_schedule_secs = None
        self._conformance_actual_secs = None
        self._exception_count = None
        self._exception_duration_secs = None
        self._impact_seconds = None
        self._schedule_length_secs = None
        self._actual_length_secs = None
        self._adherence_percentage = None
        self._conformance_percentage = None

    @property
    def day_start_offset_secs(self):
        """
        Gets the day_start_offset_secs of this HistoricalAdherenceDayMetrics.
        Start of day offset in seconds relative to query start time

        :return: The day_start_offset_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._day_start_offset_secs

    @day_start_offset_secs.setter
    def day_start_offset_secs(self, day_start_offset_secs):
        """
        Sets the day_start_offset_secs of this HistoricalAdherenceDayMetrics.
        Start of day offset in seconds relative to query start time

        :param day_start_offset_secs: The day_start_offset_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._day_start_offset_secs = day_start_offset_secs

    @property
    def adherence_schedule_secs(self):
        """
        Gets the adherence_schedule_secs of this HistoricalAdherenceDayMetrics.
        Duration of schedule in seconds included for adherence percentage calculation

        :return: The adherence_schedule_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._adherence_schedule_secs

    @adherence_schedule_secs.setter
    def adherence_schedule_secs(self, adherence_schedule_secs):
        """
        Sets the adherence_schedule_secs of this HistoricalAdherenceDayMetrics.
        Duration of schedule in seconds included for adherence percentage calculation

        :param adherence_schedule_secs: The adherence_schedule_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._adherence_schedule_secs = adherence_schedule_secs

    @property
    def conformance_schedule_secs(self):
        """
        Gets the conformance_schedule_secs of this HistoricalAdherenceDayMetrics.
        Total scheduled duration in seconds for OnQueue activities

        :return: The conformance_schedule_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._conformance_schedule_secs

    @conformance_schedule_secs.setter
    def conformance_schedule_secs(self, conformance_schedule_secs):
        """
        Sets the conformance_schedule_secs of this HistoricalAdherenceDayMetrics.
        Total scheduled duration in seconds for OnQueue activities

        :param conformance_schedule_secs: The conformance_schedule_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._conformance_schedule_secs = conformance_schedule_secs

    @property
    def conformance_actual_secs(self):
        """
        Gets the conformance_actual_secs of this HistoricalAdherenceDayMetrics.
        Total actually worked duration in seconds for OnQueue activities

        :return: The conformance_actual_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._conformance_actual_secs

    @conformance_actual_secs.setter
    def conformance_actual_secs(self, conformance_actual_secs):
        """
        Sets the conformance_actual_secs of this HistoricalAdherenceDayMetrics.
        Total actually worked duration in seconds for OnQueue activities

        :param conformance_actual_secs: The conformance_actual_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._conformance_actual_secs = conformance_actual_secs

    @property
    def exception_count(self):
        """
        Gets the exception_count of this HistoricalAdherenceDayMetrics.
        Total number of adherence exceptions for this user

        :return: The exception_count of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._exception_count

    @exception_count.setter
    def exception_count(self, exception_count):
        """
        Sets the exception_count of this HistoricalAdherenceDayMetrics.
        Total number of adherence exceptions for this user

        :param exception_count: The exception_count of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._exception_count = exception_count

    @property
    def exception_duration_secs(self):
        """
        Gets the exception_duration_secs of this HistoricalAdherenceDayMetrics.
        Total duration in seconds of adherence exceptions for this user

        :return: The exception_duration_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._exception_duration_secs

    @exception_duration_secs.setter
    def exception_duration_secs(self, exception_duration_secs):
        """
        Sets the exception_duration_secs of this HistoricalAdherenceDayMetrics.
        Total duration in seconds of adherence exceptions for this user

        :param exception_duration_secs: The exception_duration_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._exception_duration_secs = exception_duration_secs

    @property
    def impact_seconds(self):
        """
        Gets the impact_seconds of this HistoricalAdherenceDayMetrics.
        The impact duration in seconds of current adherence state for this user

        :return: The impact_seconds of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._impact_seconds

    @impact_seconds.setter
    def impact_seconds(self, impact_seconds):
        """
        Sets the impact_seconds of this HistoricalAdherenceDayMetrics.
        The impact duration in seconds of current adherence state for this user

        :param impact_seconds: The impact_seconds of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._impact_seconds = impact_seconds

    @property
    def schedule_length_secs(self):
        """
        Gets the schedule_length_secs of this HistoricalAdherenceDayMetrics.
        Total duration in seconds for all scheduled activities

        :return: The schedule_length_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._schedule_length_secs

    @schedule_length_secs.setter
    def schedule_length_secs(self, schedule_length_secs):
        """
        Sets the schedule_length_secs of this HistoricalAdherenceDayMetrics.
        Total duration in seconds for all scheduled activities

        :param schedule_length_secs: The schedule_length_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._schedule_length_secs = schedule_length_secs

    @property
    def actual_length_secs(self):
        """
        Gets the actual_length_secs of this HistoricalAdherenceDayMetrics.
        Total duration in seconds for all actually worked activities

        :return: The actual_length_secs of this HistoricalAdherenceDayMetrics.
        :rtype: int
        """
        return self._actual_length_secs

    @actual_length_secs.setter
    def actual_length_secs(self, actual_length_secs):
        """
        Sets the actual_length_secs of this HistoricalAdherenceDayMetrics.
        Total duration in seconds for all actually worked activities

        :param actual_length_secs: The actual_length_secs of this HistoricalAdherenceDayMetrics.
        :type: int
        """
        
        self._actual_length_secs = actual_length_secs

    @property
    def adherence_percentage(self):
        """
        Gets the adherence_percentage of this HistoricalAdherenceDayMetrics.
        Total adherence percentage for this user, in the scale of 0 - 100

        :return: The adherence_percentage of this HistoricalAdherenceDayMetrics.
        :rtype: float
        """
        return self._adherence_percentage

    @adherence_percentage.setter
    def adherence_percentage(self, adherence_percentage):
        """
        Sets the adherence_percentage of this HistoricalAdherenceDayMetrics.
        Total adherence percentage for this user, in the scale of 0 - 100

        :param adherence_percentage: The adherence_percentage of this HistoricalAdherenceDayMetrics.
        :type: float
        """
        
        self._adherence_percentage = adherence_percentage

    @property
    def conformance_percentage(self):
        """
        Gets the conformance_percentage of this HistoricalAdherenceDayMetrics.
        Total conformance percentage for this user, in the scale of 0 - 100. Conformance percentage can be greater than 100 when the actual on queue time is greater than the scheduled on queue time for the same period.

        :return: The conformance_percentage of this HistoricalAdherenceDayMetrics.
        :rtype: float
        """
        return self._conformance_percentage

    @conformance_percentage.setter
    def conformance_percentage(self, conformance_percentage):
        """
        Sets the conformance_percentage of this HistoricalAdherenceDayMetrics.
        Total conformance percentage for this user, in the scale of 0 - 100. Conformance percentage can be greater than 100 when the actual on queue time is greater than the scheduled on queue time for the same period.

        :param conformance_percentage: The conformance_percentage of this HistoricalAdherenceDayMetrics.
        :type: float
        """
        
        self._conformance_percentage = conformance_percentage

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SmsAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SmsAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'street': 'str',
            'city': 'str',
            'region': 'str',
            'postal_code': 'str',
            'country_code': 'str',
            'validated': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'street': 'street',
            'city': 'city',
            'region': 'region',
            'postal_code': 'postalCode',
            'country_code': 'countryCode',
            'validated': 'validated',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._street = None
        self._city = None
        self._region = None
        self._postal_code = None
        self._country_code = None
        self._validated = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SmsAddress.
        The id of this address.

        :return: The id of this SmsAddress.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SmsAddress.
        The id of this address.

        :param id: The id of this SmsAddress.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SmsAddress.


        :return: The name of this SmsAddress.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SmsAddress.


        :param name: The name of this SmsAddress.
        :type: str
        """
        
        self._name = name

    @property
    def street(self):
        """
        Gets the street of this SmsAddress.
        The number and street address where this address is located.

        :return: The street of this SmsAddress.
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """
        Sets the street of this SmsAddress.
        The number and street address where this address is located.

        :param street: The street of this SmsAddress.
        :type: str
        """
        
        self._street = street

    @property
    def city(self):
        """
        Gets the city of this SmsAddress.
        The city in which this address is in

        :return: The city of this SmsAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this SmsAddress.
        The city in which this address is in

        :param city: The city of this SmsAddress.
        :type: str
        """
        
        self._city = city

    @property
    def region(self):
        """
        Gets the region of this SmsAddress.
        The state or region this address is in

        :return: The region of this SmsAddress.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this SmsAddress.
        The state or region this address is in

        :param region: The region of this SmsAddress.
        :type: str
        """
        
        self._region = region

    @property
    def postal_code(self):
        """
        Gets the postal_code of this SmsAddress.
        The postal code this address is in

        :return: The postal_code of this SmsAddress.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this SmsAddress.
        The postal code this address is in

        :param postal_code: The postal_code of this SmsAddress.
        :type: str
        """
        
        self._postal_code = postal_code

    @property
    def country_code(self):
        """
        Gets the country_code of this SmsAddress.
        The ISO country code of this address

        :return: The country_code of this SmsAddress.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """
        Sets the country_code of this SmsAddress.
        The ISO country code of this address

        :param country_code: The country_code of this SmsAddress.
        :type: str
        """
        
        self._country_code = country_code

    @property
    def validated(self):
        """
        Gets the validated of this SmsAddress.
        In some countries, addresses are validated to comply with local regulation. In those countries, if the address you provide does not pass validation, it will not be accepted as an Address. This value will be true if the Address has been validated, or false for countries that don't require validation or if the Address is non-compliant.

        :return: The validated of this SmsAddress.
        :rtype: bool
        """
        return self._validated

    @validated.setter
    def validated(self, validated):
        """
        Sets the validated of this SmsAddress.
        In some countries, addresses are validated to comply with local regulation. In those countries, if the address you provide does not pass validation, it will not be accepted as an Address. This value will be true if the Address has been validated, or false for countries that don't require validation or if the Address is non-compliant.

        :param validated: The validated of this SmsAddress.
        :type: bool
        """
        
        self._validated = validated

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SmsAddress.
        The URI for this object

        :return: The self_uri of this SmsAddress.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SmsAddress.
        The URI for this object

        :param self_uri: The self_uri of this SmsAddress.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationCobrowseEventTopicCobrowseMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationCobrowseEventTopicCobrowseMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'QueueConversationCobrowseEventTopicUriReference',
            'queue': 'QueueConversationCobrowseEventTopicUriReference',
            'team': 'QueueConversationCobrowseEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'QueueConversationCobrowseEventTopicErrorBody',
            'script': 'QueueConversationCobrowseEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'QueueConversationCobrowseEventTopicUriReference',
            'external_organization': 'QueueConversationCobrowseEventTopicUriReference',
            'wrapup': 'QueueConversationCobrowseEventTopicWrapup',
            'conversation_routing_data': 'QueueConversationCobrowseEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'QueueConversationCobrowseEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'cobrowse_session_id': 'str',
            'cobrowse_role': 'str',
            'viewer_url': 'str',
            'provider_event_time': 'datetime',
            'controlling': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'cobrowse_session_id': 'cobrowseSessionId',
            'cobrowse_role': 'cobrowseRole',
            'viewer_url': 'viewerUrl',
            'provider_event_time': 'providerEventTime',
            'controlling': 'controlling'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._cobrowse_session_id = None
        self._cobrowse_role = None
        self._viewer_url = None
        self._provider_event_time = None
        self._controlling = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param id: The id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The name of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param name: The name of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The address of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param address: The address of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The start_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param start_time: The start_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The connected_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param connected_time: The connected_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The end_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param end_time: The end_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The start_hold_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param start_hold_time: The start_hold_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The purpose of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param purpose: The purpose of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param state: The state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The direction of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param direction: The direction of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The disconnect_type of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param disconnect_type: The disconnect_type of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The held of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param held: The held of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The wrapup_required of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param wrapup_required: The wrapup_required of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The wrapup_prompt of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The user of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param user: The user of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The queue of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param queue: The queue of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The team of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param team: The team of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The attributes of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param attributes: The attributes of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The error_info of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param error_info: The error_info of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The script of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param script: The script of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The wrapup_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The wrapup_skipped of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The alerting_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The provider of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param provider: The provider of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The external_contact of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param external_contact: The external_contact of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The external_organization of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param external_organization: The external_organization of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The wrapup of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param wrapup: The wrapup of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The conversation_routing_data of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The peer of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param peer: The peer of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The screen_recording_state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The flagged_reason of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param flagged_reason: The flagged_reason of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The journey_context of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: QueueConversationCobrowseEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param journey_context: The journey_context of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: QueueConversationCobrowseEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The start_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param start_acw_time: The start_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The end_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param end_acw_time: The end_acw_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def cobrowse_session_id(self):
        """
        Gets the cobrowse_session_id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The cobrowse_session_id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._cobrowse_session_id

    @cobrowse_session_id.setter
    def cobrowse_session_id(self, cobrowse_session_id):
        """
        Sets the cobrowse_session_id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param cobrowse_session_id: The cobrowse_session_id of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._cobrowse_session_id = cobrowse_session_id

    @property
    def cobrowse_role(self):
        """
        Gets the cobrowse_role of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The cobrowse_role of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._cobrowse_role

    @cobrowse_role.setter
    def cobrowse_role(self, cobrowse_role):
        """
        Sets the cobrowse_role of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param cobrowse_role: The cobrowse_role of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._cobrowse_role = cobrowse_role

    @property
    def viewer_url(self):
        """
        Gets the viewer_url of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The viewer_url of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: str
        """
        return self._viewer_url

    @viewer_url.setter
    def viewer_url(self, viewer_url):
        """
        Sets the viewer_url of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param viewer_url: The viewer_url of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: str
        """
        
        self._viewer_url = viewer_url

    @property
    def provider_event_time(self):
        """
        Gets the provider_event_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The provider_event_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: datetime
        """
        return self._provider_event_time

    @provider_event_time.setter
    def provider_event_time(self, provider_event_time):
        """
        Sets the provider_event_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param provider_event_time: The provider_event_time of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: datetime
        """
        
        self._provider_event_time = provider_event_time

    @property
    def controlling(self):
        """
        Gets the controlling of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :return: The controlling of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :rtype: list[str]
        """
        return self._controlling

    @controlling.setter
    def controlling(self, controlling):
        """
        Sets the controlling of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.


        :param controlling: The controlling of this QueueConversationCobrowseEventTopicCobrowseMediaParticipant.
        :type: list[str]
        """
        
        self._controlling = controlling

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

